/*
 *
 *  This file is part of the XForms library package.
 *
 * XForms is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1, or
 * (at your option) any later version.
 *
 * XForms is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with XForms; see the file COPYING.  If not, write to
 * the Free Software Foundation, 59 Temple Place - Suite 330, Boston,
 * MA 02111-1307, USA.
 *
 */

/**
 * \file pscrollbar.h
 */

#ifndef PSCROLLBAR_H_
#define PSCROLLBAR_H_

typedef struct
{
    FL_OBJECT * scrollbar;
    FL_OBJECT * slider;
    FL_OBJECT * up;
	FL_OBJECT * down;
    double      increment;
    long        reserve[ 10 ];
} FLI_SCROLLBAR_SPEC;


#endif
